pub struct ProverOnlyData<SC: SGC> {
pub preprocessed_prover_data: Option<<SC::Pcs as Pcs<Challenge<SC>, SC::Challenger>>::ProverData>,
}Expand description
Prover-exclusive data not shared with the verifier.
This contains the PCS prover data for preprocessed traces, which is only needed during proving.
Fields
preprocessed_prover_data: Option<<SC::Pcs as Pcs<Challenge<SC>, SC::Challenger>>::ProverData>PCS prover data for preprocessed traces.
Present only when at least one instance has preprocessed columns.
Implementations
Sourceimpl<SC: SGC> ProverOnlyData<SC>
impl<SC: SGC> ProverOnlyData<SC>
Sourcepub const fn empty() -> Self
pub const fn empty() -> Self
Create empty ProverOnlyData with no preprocessed prover data.