pub struct CommonData<SC: SGC> {
pub preprocessed: Option<GlobalPreprocessed<SC>>,
pub lookups: Vec<Vec<Lookup<Val<SC>>>>,
}Expand description
Struct storing data common to both the prover and verifier.
Fields
preprocessed: Option<GlobalPreprocessed<SC>>Optional global preprocessed commitment shared by all instances.
When None, no instance uses preprocessed columns.
lookups: Vec<Vec<Lookup<Val<SC>>>>The lookups used by each STARK instance.
There is one Vec<Lookup<Val<SC>>> per STARK instance.
They are stored in the same order as the STARK instance inputs provided to new.
Implementations
Sourceimpl<SC: SGC> CommonData<SC>
impl<SC: SGC> CommonData<SC>
pub const fn new( preprocessed: Option<GlobalPreprocessed<SC>>, lookups: Vec<Vec<Lookup<Val<SC>>>>, ) -> Self
Sourcepub fn empty(num_instances: usize) -> Self
pub fn empty(num_instances: usize) -> Self
Create CommonData with no preprocessed columns or lookups.
Use this when none of your Air implementations have preprocessed columns or lookups.